from distutils.core import setup

setup(
        name        = 'powerxy',
        version     = '1.0.2',
        py_modules  = ['powerxy'],
        author      = 'arthur4it',
        author_email= 'arthur4it@gmail.com',
        url         = 'http://home.ustc.edu.cn/~arthury',
        description = 'A utility for evaluating power(x,y). Add hint for user',
        )
